/* read ultrasonic distance sensor
 
 * 
 * read an ultrasonic distance sensor using I2C bus
 *
 * uses SRF02 library from grapelabs, http://www.grapelabs.de
 * uses metro library, http://www.arduino.cc/playground/Code/Metro
 *
 * remove red jumper near built-in poti to use I2C bus
 * connect plug with three wires on A5 and plug with one wire on A4
 *
 
 * SensorAktor Workshop
 * Lab3 2008
 * Kunsthochschule fuer Medien Koeln
 * Academy of Media Arts Cologne
 * http://interface.khm.de
 
 * pin mapping SensorAktor Shield (import <SensorAktor.h> to get already defined mapping)
 *
 * analog inputs: a0 = pin0, a1 = pin1, a2 = pin2, a3 = pin3, a4 = pin4, a5 = pin5
 * built-in poti: poti = pin5
 * amplified input: mic = pin0
 * switches: s1 = pin1, s2 = pin2, s3 = pin3
 * leds: led1 = pin3, led2 = pin5, led3 = pin6
 * power outs: out1 = pin3, out2 = pin5, out3 = pin6
 * motor outs: motor1_1 = pin11, motor1_2 = pin12, motor2_1 = pin13, motor2_2 = pin8
 * motor pwms: pwmMotor1 = pin9, pwmMotor2 = pin10
 * servo outs: servo1 = pin2, servo2 = pin4, servo3 = pin7

 */


// import sensor aktor library for pin mapping
#include <SensorAktor.h>

// import wire library to use I2C bus
#include "Wire.h"

// import SRF02 library
#include "SRF02.h"
// create instance for ultrasonic distance sensor
SRF02 distanceSensor(0x70, SRF02_CENTIMETERS);

// import metro library (for serial output)
#include <Metro.h>
// create instace for metro
Metro serialMetro = Metro(10);

void setup()
{
  
  // start serial communication (for printing to serial port)
  Serial.begin(9600);
  
  // start I2C communication
  Wire.begin();
}

void loop()
{
  
  // update sensor data
  SRF02::update();
  
  // check serial metro
  if(serialMetro.check() == 1){
    Serial.println(distanceSensor.read());
  }
  
}
